@@ -48,16 +48,23 @@ rwa_read <- function(x,
   chat_raw <- chat_raw[!chat_raw == ""]
   time <- stri_extract_first_regex(
     str = chat_raw,
-    pattern = "^\\d+-\\d+-\\d+.*-|[^-]+ - "
+    pattern = "^\\d{2,4}.\\d{2}.\\d{2,4} - \\d{2}:\\d{2}[^;]+;|^\\d{2,4}-\\d{2}-\\d{2,4}[^-]+ -|[^-]+ - "
   )
   if (sum(is.na(time)) > (length(time) / 2)) {
     time <- stri_extract_first_regex(str = chat_raw,
                                      pattern = "[^]]+] ")
   }
-  if (sum(is.na(time)) == length(time)) {
+  if (sum(is.na(time)) > (length(time) / 2)) {
     time <- stri_extract_first_regex(str = chat_raw,
-                                     pattern = "^.*\\d+:\\d+")
+                                     pattern = "^[^A-z]*\\d{1,2}:\\d{1,2}")
   }
+
+  proper_time <- stri_detect_regex(
+    str = time,
+    pattern = "\\d{2,4}.\\d{2}.\\d{2,4}|\\d{1,2}:\\d{1,2} [APM]"
+  )
+  time[!proper_time] <- NA
+
   for (l in rev(which(is.na(time)))) {
     chat_raw[l - 1] <- stri_paste(chat_raw[l - 1], chat_raw[l],
                                   sep = "\n")
@@ -99,6 +106,12 @@ rwa_read <- function(x,
                                     pattern = ": ",
                                     replacement = "")
 
+  if (isTRUE(any(stri_detect_regex(head(author, 10), "^ - ")))) {
+    author <- stri_replace_first_regex(str = author,
+                                       pattern = "^ - ",
+                                       replacement = "")
+  }
+
   if (verbose) status("author extracted")
 
   tbl <- tibble::tibble(
@@ -173,7 +186,8 @@ rwa_read_lines <- function(x, verbose, start_time = NULL, encoding, ...) {
     }
   } else {
     stop("Provide either a path to one or multiple txt or zip files of a ",
-         "WhatsApp history or the history itself as character object.")
+         "WhatsApp history or the history itself as character object ",
+         "(length > 1).")
   }
   if (length(zps) > 0) {
     names(chat_raw) <- stri_replace_last_fixed(names(chat_raw), x[zps], src)
@@ -192,17 +206,32 @@ rwa_read_lines <- function(x, verbose, start_time = NULL, encoding, ...) {
 rwa_parse_time <- function(time, format, tz) {
   if (is.null(format)) {
     formats <- c(
-      "dd.MM.yyyy, hh:mm:ss a",
-      "dd.MM.yyyy, hh:mm a",
-      "dd.MM.yyyy, HH:mm:ss",
-      "dd.MM.yyyy, HH:mm",
-      "MM.dd.yyyy, hh:mm:ss a",
-      "MM.dd.yyyy, hh:mm a",
-      "MM.dd.yyyy, HH:mm:ss",
-      "MM.dd.yyyy, HH:mm"
+      "dd.MM.yyyy hh:mm:ss a",
+      "dd.MM.yyyy hh:mm a",
+      "dd.MM.yyyy HH:mm:ss",
+      "dd.MM.yyyy HH:mm",
+      "MM.dd.yyyy hh:mm:ss a",
+      "MM.dd.yyyy hh:mm a",
+      "MM.dd.yyyy HH:mm:ss",
+      "MM.dd.yyyy HH:mm"
     )
+
+    time <- stri_replace_all_fixed(
+      time,
+      c("a.m.", "p.m."),
+      c("AM", "PM"),
+      vectorize_all = FALSE
+    )
+
+    time <- stri_replace_all_regex(
+      time,
+      c("[^[0-9.:/\\-APM]]", "\\s+"),
+      c(" ", " "),
+      vectorize_all = FALSE
+    )
+
     if (any(stri_detect_fixed(time, "."))) {
-      if (sum(stri_detect_regex(time, "\\d+.\\d+.\\d{2}")) >
+      if (sum(stri_detect_regex(time, "\\d+.\\d+.\\d{1,2}")) >
           (length(time) * 0.9)) {
         formats <- stri_replace_all_fixed(
           formats,
@@ -216,13 +245,21 @@ rwa_parse_time <- function(time, format, tz) {
         ".",
         "/"
       )
-      if (sum(stri_detect_regex(time, "\\d+/\\d+/\\d{2}")) >
+      if (sum(stri_detect_regex(time, "\\b\\d{1,2}/\\d{1,2}/\\d{2}")) >
           (length(time) * 0.9)) {
         formats <- stri_replace_all_fixed(
           formats,
           "yyyy",
           "yy"
         )
+      } else if (sum(stri_detect_regex(time, "\\b\\d{4}/\\d+/\\d{1,2}")) >
+                 (length(time) * 0.9)) {
+        formats <- stri_replace_all_fixed(
+          formats,
+          "dd/MM/yyyy",
+          "yyyy/MM/dd",
+          vectorize_all = FALSE
+        )
       }
     } else if (any(stri_detect_fixed(time, "-"))) {
       formats <- stri_replace_all_fixed(
@@ -230,13 +267,21 @@ rwa_parse_time <- function(time, format, tz) {
         ".",
         "-"
       )
-      if (sum(stri_detect_regex(time, "\\d+-\\d+-\\d{2}")) >
+      if (sum(stri_detect_regex(time, "\\b\\d{1,2}-\\d{1,2}-\\d+")) >
           (length(time) * 0.9)) {
         formats <- stri_replace_all_fixed(
           formats,
           "yyyy",
           "yy"
         )
+      } else if (sum(stri_detect_regex(time, "\\b\\d{4}-\\d+-\\d{1,2}")) >
+                 (length(time) * 0.9)) {
+        formats <- stri_replace_all_fixed(
+          formats,
+          "dd-MM-yyyy",
+          "yyyy-MM-dd",
+          vectorize_all = FALSE
+        )
       }
     } else {
       formats <- c(
